# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Boolean.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="Boolean.proto",
    package="tzrpc.proto",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\rBoolean.proto\x12\x0btzrpc.proto"\x18\n\x07\x42oolean\x12\r\n\x05value\x18\x01 \x01(\x08"!\n\x10\x42ooleanArrayList\x12\r\n\x05value\x18\x01 \x03(\x08\x62\x06proto3',
)


_BOOLEAN = _descriptor.Descriptor(
    name="Boolean",
    full_name="tzrpc.proto.Boolean",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="tzrpc.proto.Boolean.value",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=30,
    serialized_end=54,
)


_BOOLEANARRAYLIST = _descriptor.Descriptor(
    name="BooleanArrayList",
    full_name="tzrpc.proto.BooleanArrayList",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="tzrpc.proto.BooleanArrayList.value",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=56,
    serialized_end=89,
)

DESCRIPTOR.message_types_by_name["Boolean"] = _BOOLEAN
DESCRIPTOR.message_types_by_name["BooleanArrayList"] = _BOOLEANARRAYLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Boolean = _reflection.GeneratedProtocolMessageType(
    "Boolean",
    (_message.Message,),
    {
        "DESCRIPTOR": _BOOLEAN,
        "__module__": "Boolean_pb2"
        # @@protoc_insertion_point(class_scope:tzrpc.proto.Boolean)
    },
)
_sym_db.RegisterMessage(Boolean)

BooleanArrayList = _reflection.GeneratedProtocolMessageType(
    "BooleanArrayList",
    (_message.Message,),
    {
        "DESCRIPTOR": _BOOLEANARRAYLIST,
        "__module__": "Boolean_pb2"
        # @@protoc_insertion_point(class_scope:tzrpc.proto.BooleanArrayList)
    },
)
_sym_db.RegisterMessage(BooleanArrayList)


# @@protoc_insertion_point(module_scope)
